pub type StrippedRoomServerAclEvent = StrippedStateEvent<PossiblyRedactedRoomServerAclEventContent>;Expand description
An m.room.server_acl event from an invited room preview.
Aliased Type
pub struct StrippedRoomServerAclEvent {
pub content: RoomServerAclEventContent,
pub sender: OwnedUserId,
pub state_key: EmptyStateKey,
}Fields
content: RoomServerAclEventContentData specific to the event type.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
state_key: EmptyStateKeyA unique key which defines the overwriting semantics for this piece of room state.
This is often an empty string, but some events send a UserId to show which user the event
affects.